# texto_no_espelho

Description. 
O pacote texto_no_espleho é usando para:
	- Receber um texto qualquer
	- imprimir o retorno original e espelhado

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install texto_no_espelho

```bash
pip install texto_no_espelho
```

## Author
Israel Ruiz

## License
[MIT](https://choosealicense.com/licenses/mit/)